@@ -7,7 +7,7 @@ use Alien::Build;
 use base qw( Module::Build );
 
 # ABSTRACT: Alien::Build installer class for Module::Build
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub new
@@ -34,6 +34,15 @@ sub new
   $self->_add_prereq( "${_}_requires", 'Alien::Build::MB' => '0.01' ) for qw( configure build );
   $self->add_to_cleanup("_alien");
 
+  foreach my $hook_name (qw( test_ffi test_share test_system ))
+  {
+    if($build->meta->has_hook($hook_name))
+    {
+      $self->_add_prereq( "configure_requires", 'Alien::Build::MB' => '0.05');
+      last;
+    }
+  }
+
   my %config_requires = %{ $build->requires('configure') };
   foreach my $module (keys %config_requires)
   {
@@ -150,6 +159,28 @@ sub ACTION_alien_build
   $self;
 }
 
+
+sub ACTION_alien_test
+{
+  my($self) = @_;
+  $self->depends_on('alien_build');
+  
+  my $build = $self->alien_build;
+  if($build->can('test'))
+  {
+    $build->test;
+    $build->checkpoint;
+  }
+  $self;  
+}
+
+sub ACTION_test
+{
+  my($self) = @_;
+  $self->depends_on('alien_test');
+  $self->SUPER::ACTION_test;
+}
+
 sub ACTION_code
 {
   my($self) = @_;
@@ -171,7 +202,7 @@ Alien::Build::MB - Alien::Build installer class for Module::Build
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -240,6 +271,12 @@ not do anything.
 
 Build the package from source.
 
+=head2 ACTION_alien_test
+
+ ./Build alien_test
+
+Run the package tests, if there are any.
+
 =head1 SEE ALSO
 
 L<Alien::Build>, L<Alien::Build::MM>, L<Alien::Base::ModuleBuild>
